pub struct ArchiveEntry {
pub path: String,
pub kind: ArchiveEntryKind,
pub size: Option<u64>,
pub mode: Option<u32>,
pub modified_unix_seconds: Option<i64>,
}Expand description
Generic archive entry metadata.
Fields
path: StringArchive-internal path.
kind: ArchiveEntryKindArchive entry kind.
size: Option<u64>Entry payload size in bytes, when known.
mode: Option<u32>Entry mode or permission bits, when known.
modified_unix_seconds: Option<i64>Unix timestamp seconds for the modified time, when known.
Implementations
Sourceimpl ArchiveEntry
impl ArchiveEntry
Sourcepub fn new(path: impl Into<String>, kind: ArchiveEntryKind) -> Self
pub fn new(path: impl Into<String>, kind: ArchiveEntryKind) -> Self
Creates archive entry metadata from a path and kind.
Sourcepub const fn with_modified_unix_seconds(self, seconds: i64) -> Self
pub const fn with_modified_unix_seconds(self, seconds: i64) -> Self
Adds known modified timestamp metadata.
Sourcepub const fn kind(&self) -> ArchiveEntryKind
pub const fn kind(&self) -> ArchiveEntryKind
Returns the archive entry kind.
Sourcepub const fn modified_unix_seconds(&self) -> Option<i64>
pub const fn modified_unix_seconds(&self) -> Option<i64>
Returns the known modified timestamp.
Sourcepub const fn is_directory(&self) -> bool
pub const fn is_directory(&self) -> bool
Returns whether this is a directory entry.
Sourcepub const fn is_symlink(&self) -> bool
pub const fn is_symlink(&self) -> bool
Returns whether this is a symbolic link entry.