ArchiveEntry

Struct ArchiveEntry 

pub struct ArchiveEntry {
    pub path: String,
    pub kind: ArchiveEntryKind,
    pub size: Option<u64>,
    pub mode: Option<u32>,
    pub modified_unix_seconds: Option<i64>,
}
Generic archive entry metadata.

Fields

path: String

Archive-internal path.

kind: ArchiveEntryKind

Archive entry kind.

size: Option<u64>

Entry payload size in bytes, when known.

mode: Option<u32>

Entry mode or permission bits, when known.

modified_unix_seconds: Option<i64>

Unix timestamp seconds for the modified time, when known.

Implementations

Source

impl ArchiveEntry

pub fn new(path: impl Into<String>, kind: ArchiveEntryKind) -> Self

Creates archive entry metadata from a path and kind.

pub fn file(path: impl Into<String>) -> Self

Creates a regular file entry.

pub fn directory(path: impl Into<String>) -> Self

Creates a directory entry.

Creates a symbolic link entry.

pub const fn with_size(self, size: u64) -> Self

Adds known entry size metadata.

pub const fn with_mode(self, mode: u32) -> Self

Adds known entry mode metadata.

pub const fn with_modified_unix_seconds(self, seconds: i64) -> Self

Adds known modified timestamp metadata.

pub fn path(&self) -> &str

Returns the archive-internal path.

pub const fn kind(&self) -> ArchiveEntryKind

Returns the archive entry kind.

pub const fn size(&self) -> Option<u64>

Returns the known entry size.

pub const fn mode(&self) -> Option<u32>

Returns the known entry mode.

pub const fn modified_unix_seconds(&self) -> Option<i64>

Returns the known modified timestamp.

pub const fn is_file(&self) -> bool

Returns whether this is a regular file entry.

pub const fn is_directory(&self) -> bool

Returns whether this is a directory entry.

Returns whether this is a symbolic link entry.